import * as React from 'react';
import { PropsWithMetadata } from '@highlight-ui/utils-commons';
export declare type DropdownMenuProps = React.PropsWithChildren<PropsWithMetadata<{
    /** Allows providing a custom class name to the DIV element that surrounds the text */
    className?: string;
    /** Enables closing the dropdown menu when clicking outside */
    closeOnClickAnywhere?: boolean;
    /** Whether the dropdown is open or not */
    open?: boolean;
    /** Default open value */
    defaultValue?: boolean;
    /** Prevents the open state of the dropdown menu from changing (Only works when the `open` prop is *not* being used) */
    disabled?: boolean;
    /** Callback triggered whenever the open state of the dropdown menu is changed (Only works when the `open` prop is *not* being used) */
    onChange?: () => void;
    /** Callback triggered whenever the dropdown menu  is closed (Only works when the `open` prop is *not* being used) */
    onClose?: () => void;
    /** Callback triggered whenever the dropdown menu  is opened (Only works when the `open` prop is *not* being used) */
    onOpen?: () => void;
    /** Callback triggered when the open state of the dropdown menu is about to change (Only works when the `open` prop is in use) */
    onRequestToChange?: () => void;
}>> & React.ComponentPropsWithoutRef<'div'>;
declare type TState = {
    open: boolean;
    width: number | null | undefined;
};
declare class DropdownMenu extends React.PureComponent<DropdownMenuProps, TState> {
    dropdownRef: React.RefObject<HTMLDivElement>;
    static defaultProps: {
        disabled: boolean;
        open: null;
        defaultValue: boolean;
    };
    controlledComponent: boolean;
    constructor(props: DropdownMenuProps);
    componentDidMount(): void;
    componentDidUpdate(): void;
    componentWillUnmount(): void;
    get open(): boolean;
    get onToggleCallback(): (() => void) | undefined;
    dropdownCurrentRef: () => any;
    _handleClickOutside: (event: MouseEvent) => void;
    handleRequestToChange: () => void;
    handleOpen: () => void;
    handleClose: () => void;
    handleToggle: () => void;
    render(): React.ReactNode;
}
export default DropdownMenu;
